package com.ruoyi.tuya.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tuya.mapper.BusTravelMapper;
import com.ruoyi.tuya.domain.BusTravel;
import com.ruoyi.tuya.service.IBusTravelService;

/**
 * 平台游记Service业务层处理
 *
 * @author zf
 * @date 2022-07-20
 */
@Service
public class BusTravelServiceImpl implements IBusTravelService
{
    @Autowired
    private BusTravelMapper busTravelMapper;

    /**
     * 查询平台游记
     *
     * @param id 平台游记主键
     * @return 平台游记
     */
    @Override
    public BusTravel selectBusTravelById(Long id)
    {
        return busTravelMapper.selectBusTravelById(id);
    }

    /**
     * 查询平台游记列表
     *
     * @param busTravel 平台游记
     * @return 平台游记
     */
    @Override
    public List<BusTravel> selectBusTravelList(BusTravel busTravel)
    {
        return busTravelMapper.selectBusTravelList(busTravel);
    }

    /**
     * 新增平台游记
     *
     * @param busTravel 平台游记
     * @return 结果
     */
    @Override
    public int insertBusTravel(BusTravel busTravel)
    {
        return busTravelMapper.insertBusTravel(busTravel);
    }

    /**
     * 新增平台游记删除备份
     *
     * @param busTravel 平台游记删除备份
     * @return 结果
     */
    @Override
    public int insertBusTravelDiscard(Long[] ids)
    {
        return busTravelMapper.insertBusTravelDiscard(ids);
    }

    /**
     * 修改平台游记
     *
     * @param busTravel 平台游记
     * @return 结果
     */
    @Override
    public int updateBusTravel(BusTravel busTravel)
    {
        return busTravelMapper.updateBusTravel(busTravel);
    }

    /**
     * 批量删除平台游记
     *
     * @param ids 需要删除的平台游记主键
     * @return 结果
     */
    @Override
    public int deleteBusTravelByIds(Long[] ids)
    {
        return busTravelMapper.deleteBusTravelByIds(ids);
    }

    /**
     * 删除平台游记信息
     *
     * @param id 平台游记主键
     * @return 结果
     */
    @Override
    public int deleteBusTravelById(Long id)
    {
        return busTravelMapper.deleteBusTravelById(id);
    }
}
